Learn R Programming

mmabig (version 3.2-0)

print.mma.big: Print a mma.big object

Description

Print the estimation of mediation effects from an mma.big object.

Usage

# S3 method for mma.big
print(x,...)

Arguments

x

a mma object created initially call to mma, boot.med.binx, or boot.med.contx.

...

other arguments passed to the print function.

Author

Qingzhao Yu qyu@lsuhsc.edu and Bin Li bli@lsu.edu

References

Yu, Q., Fan, Y., and Wu, X. (2014) <doi:10.4172/2155-6180.1000189>. "General Multiple Mediation Analysis With an Application to Explore Racial Disparity in Breast Cancer Survival," Journal of Biometrics & Biostatistics,5(2): 189.

Yu, Q., Scribner, R.A., Leonardi, C., Zhang, L., Park, C., Chen, L., and Simonsen, N.R. (2017) <doi:10.1016/j.sste.2017.02.001>. "Exploring racial disparity in obesity: a mediation analysis considering geo-coded environmental factors," Spatial and Spatio-temporal Epidemiology, 21, 13-23.

Yu, Q., and Li, B. (2017) <doi:10.5334/hors.160>. "mma: An r package for multiple mediation analysis," Journal of Open Research Software, 5(1), 11.

Li, B. and Yu, Q. (2018). "Mediation Analysis with Large Data Sets".

See Also

"mma.big"

Examples

Run this code
#See help(mma.big)

Run the code above in your browser using DataLab