Learn R Programming

mmabig (version 3.2-0)

summary.med_iden.big: Summary method for class "med_iden.big".

Description

Compute the estimations, standard deviations and confidence intervals of the mediation effects.

Usage

# S3 method for med_iden.big
summary(object,...,only=F) 
# S3 method for summary.med_iden.big
print(x,...)

Value

The function summary.med_iden return a list of covariates and mediators as identified by a series tests.

mediator

variable names of the identified mediators, either siginicant in both full model and in relate to the predictor, or being a member of the pre-identified joint mediators.

covariate

variable names of covariates: being significant in the full model but not significantly relate with the predictor.

tests

statistical test results.

results

the original object.

Arguments

object

a med_iden object created initially call to data.org.big.

x

a summary.med_iden.big object created initially call to summary.med_iden.big

...

other arguments passed to the print function.

only

if only=T, show test results for selected covariates and mediators only.

Author

Qingzhao Yu qyu@lsuhsc.edu and Bin Li bli@lsu.edu

Details

summary.med_iden gives a list of identified mediators, covariates and the test results.

References

Yu, Q., Fan, Y., and Wu, X. (2014) <doi:10.4172/2155-6180.1000189>. "General Multiple Mediation Analysis With an Application to Explore Racial Disparity in Breast Cancer Survival," Journal of Biometrics & Biostatistics,5(2): 189.

See Also

"mma.big"

Examples

Run this code
#see help(mma.big)

Run the code above in your browser using DataLab